@@ -1,5 +1,6 @@
 from argparse import ArgumentParser
 from .dgx import create_app, delete_app, add_optional, create_module
+from ._version import __version__
 
 parser = ArgumentParser(description='Dealergeek Generator API Express', usage='DGX', )
 
@@ -31,6 +32,12 @@ parser.add_argument(
     required=False,
     help="Create a new module"
 )
+parser.add_argument(
+    "-v",
+    "--version",
+    action='store_true',
+    help="Version"
+)
 
 
 def main():
@@ -46,6 +53,8 @@ def main():
         add_optional(args.add, None)
     elif args.create:
         create_module(args.create)
+    elif args.version:
+        print(__version__)
     else:
         parser.print_help()
 
