@@ -1,15 +1,16 @@
 from flask import Blueprint, jsonify
 from flasgger import swag_from
-from utils.decorators import login_required, validate_request
+from flask_json_pattern import json_pattern
+from utils.decorators import login_required
 
 
 default = Blueprint('default', __name__)
 
 
-@default.route('/default/search', methods=['POST'])
+@default.route('/search', methods=['POST'])
 @login_required
-@validate_request({
-    'search': {'type': 'string'},
+@json_pattern({
+    'search': {'type': str},
 })
 @swag_from('./docs/search.yml')
 def search():
