@@ -121,7 +121,7 @@ def __add_module_to_run(module: str, rServerPath: str, mCPath: str):
                 break
     if vmodule:
         lnmodule = "from modules.{0}.{0}_controller import {1}".format(module, vmodule)
-        lnregistre = "app.register_blueprint(%s)" % vmodule
+        lnregistre = "app.register_blueprint(%s" % vmodule
         # lectura del archivo runServer.py
         with open(rServerPath, 'r+') as fl:
             data = fl.read()  # lee todo el texto
@@ -140,7 +140,7 @@ def __add_module_to_run(module: str, rServerPath: str, mCPath: str):
                             index += 1
                     elif flag == 'register' and inregistre is False:
                         if ln.strip() == "":
-                            lines.insert(index, lnregistre)
+                            lines.insert(index, lnregistre + ", url_prefix='/%s')" % module)
                             break
                     elif flag == '':
                         if "from modules." in ln:
