@@ -1,13 +1,14 @@
 from flask import Blueprint, request, jsonify, session
 from flasgger import swag_from
-from utils.decorators import login_required, validate_request
+from flask_json_pattern import json_pattern
+from utils.decorators import login_required
 from dgapi import DGAPI
 
 
 brand = Blueprint('brand', __name__)
 
 
-@brand.route('/brand/get_all', methods=['GET'])
+@brand.route('/get_all', methods=['GET'])
 @login_required
 @swag_from('./docs/get_all.yml')
 def get_all():
@@ -15,7 +16,7 @@ def get_all():
     return jsonify(resp.json())
 
 
-@brand.route('/brand/get_by_dealer', methods=['GET'])
+@brand.route('/get_by_dealer', methods=['GET'])
 @login_required
 @swag_from('./docs/get_by_dealer.yml')
 def get_by_dealer():
@@ -23,10 +24,10 @@ def get_by_dealer():
     return jsonify(resp.json())
 
 
-@brand.route('/brand/search', methods=['POST'])
+@brand.route('/search', methods=['POST'])
 @login_required
-@validate_request({
-    'search': {'type': 'string'},
+@json_pattern({
+    'search': {'type': str},
 })
 @swag_from('./docs/search.yml')
 def search():
