@@ -1,16 +1,17 @@
 from flask import Blueprint, request, jsonify
 from flasgger import swag_from
-from utils.decorators import login_required, validate_request
+from flask_json_pattern import json_pattern
+from utils.decorators import login_required
 from dgapi import DGAPI
 
 
 psnl = Blueprint('personnel', __name__)
 
 
-@psnl.route('/personnel/search', methods=['POST'])
+@psnl.route('/search', methods=['POST'])
 @login_required
-@validate_request({
-    'search': {'type': 'string'},
+@json_pattern({
+    'search': {'type': str},
 })
 @swag_from('./docs/search.yml')
 def search():
@@ -18,10 +19,10 @@ def search():
     return jsonify(resp.json())
 
 
-@psnl.route('/personnel/get_by_id', methods=['POST'])
+@psnl.route('/get_by_id', methods=['POST'])
 @login_required
-@validate_request({
-    'id': {'type': 'number'},
+@json_pattern({
+    'id': {'type': int},
 })
 @swag_from('./docs/get_by_id.yml')
 def get_by_id():
@@ -33,10 +34,10 @@ def get_by_id():
     return jsonify(None)
 
 
-@psnl.route('/personnel/update', methods=['POST'])
+@psnl.route('/update', methods=['POST'])
 @login_required
-@validate_request({
-    'id': {'type': 'number'},
+@json_pattern({
+    'id': {'type': int},
 })
 @swag_from('./docs/update.yml')
 def update():
@@ -45,7 +46,7 @@ def update():
     return jsonify(resp.json())
 
 
-@psnl.route('/personnel/get_roles', methods=['GET'])
+@psnl.route('/get_roles', methods=['GET'])
 @login_required
 @swag_from('./docs/get_roles.yml')
 def get_roles():
