@@ -3,12 +3,15 @@ import eventlet
 eventlet.monkey_patch()
 
 # dependencias
-from flask import Flask, jsonify, request
+from flask import Flask, jsonify, request, make_response
+from flask_json_pattern import ValidationError
 from mongoCon import MongoCon
 from flask_socketio import SocketIO
 from const import ENV, MONGO_CONN
 from utils.helpers import CustomJSONEncoder
 from datetime import datetime
+from werkzeug import exceptions
+import traceback
 import json
 
 
@@ -26,6 +29,21 @@ def index():
     return jsonify({"message": "Welcome to <<API_NAME>> API", "ENV": ENV, "db": MONGO_CONN['database']})
 
 
+@app.errorhandler(400)
+def bad_request(error):
+    if isinstance(error.description, ValidationError):
+        return make_response(jsonify({'msg': error.description.message}), 400)
+    return make_response(jsonify({'msg': str(error)}), 400)
+
+
+@app.errorhandler(Exception)
+def handle_exception(e):
+    traceback.print_exc()
+    if isinstance(e, exceptions.HTTPException):
+        return make_response(jsonify({'msg': e.name}), e.code)
+    return make_response(jsonify({'msg': str(e)}), 500)
+
+
 @app.before_request
 def before_request_func():
     with MongoCon() as cnx:
@@ -39,4 +57,4 @@ def before_request_func():
             "browser": request.user_agent.browser,
             "language": request.user_agent.language,
             "platform": request.user_agent.platform
-        })
\ No newline at end of file
+        })
