@@ -15,7 +15,7 @@ DIRECTORY_TEMP_PATH = path.join(ROOT_API, "__temp__")
 ENV = "DEV"
 
 # puerto
-PORT = '<<PORT>>'
+PORT = <<PORT>>
 
 # identificador de la aplicacion
 APPLICATION_CODE = '<<APPLICATION_CODE>>'
@@ -23,6 +23,10 @@ APPLICATION_CODE = '<<APPLICATION_CODE>>'
 # IP Local servidor api dealergeek
 DGAPI_SERVER = ''
 
+# Telegram BOT
+TELEGRAM_TOKEN = ""
+TELEGRAM_CHAT_ID = ""
+
 
 # cadena de coneccion
 MONGO_CONN = {
