@@ -12,7 +12,7 @@ class DGAPI(object):
     def send_request(self, type_method: str, endpoint: str, body: dict, headers: dict) -> requests.Response:
         nheaders = {**dict(request.headers), "application-code": APPLICATION_CODE}
         headers and nheaders.update(headers)
-        return requests.request(type_method, r"http://%s/%s" % (self.server_address, endpoint), json=body, headers=nheaders)
+        return requests.request(type_method, self.server_address + endpoint, json=body, headers=nheaders)
 
     @classmethod
     def post(self, method: str, body: dict, headers: dict = {}) -> requests.Response:
