@@ -11,8 +11,8 @@ CORS(app)
 
 # registra los demas modulos
 app.register_blueprint(auth)
-app.register_blueprint(ite)
-app.register_blueprint(recycle)
+app.register_blueprint(ite, url_prefix='/item')
+app.register_blueprint(recycle, url_prefix='/recycle')
 
 
 # configuracion del swagger
